pva.gompertz(obs.error = "none", fixed)
ricker(obs.error = "none", fixed)
thetalogistic(obs.error = "none", fixed)
thetalogistic_D(obs.error = "none", fixed)
bevertonholt(obs.error = "none", fixed)"none", "poisson", or "normal".pvamodel-class)pva to fit the following
growth models to a given population time series assuming both
with and without observation error. When assuming the presence of
observation error, either the Normal
or the Poisson observation error model must be assumed within the
state-space model formulation (Nadeem and Lele, 2012). The growth
models are defined as follows.
Gompertz (gompertz):
$$x_{t} = a + x_{t-1} + b x_{t-1} + \epsilon_{t}$$
where $x_{t}$ is log abundance at time $t$ and
$\epsilon_{t} \sim Normal(0, \sigma^2)$.
Ricker (ricker):
$$x_{t} = x_{t-1} + a + b e^{x_{t-1}} + \epsilon_{t}$$
where $x_{t}$ is log abundance at time
$t$ and $\epsilon_{t} \sim Normal(0, \sigma^2$.
Theta-Logistic (thetalogistic):
$$x_{t} = x_{t-1} + r[1-(e^{x_{t-1}}/K)^theta] + \epsilon_{t}$$
where $x_{t}$ is log abundance at time
$t$ and $\epsilon_{t} \sim Normal(0, \sigma^2$.
Theta-Logistic with Demographic Variability
(thetalogistic_D):
$$x_{t} = x_{t-1} + r[1-(e^{x_{t-1}}/K)^theta] + \epsilon_{t}$$
where $x_{t}$ is log abundance at time
$t$ and $\epsilon_{t} \sim Normal(0, \sigma^2 + sigma.d^2$, where $sigma.d^2$
is the demographic variability. If $sigma.d^2$ is
missing or fixed at zero, Theta-Logistic model is fitted instead.
Generilzed Beverton-Holt (bevertonholt):
$$x_{t} = x_{t-1} + r- log[1+(e^{x_{t-1}}/K)^theta] + \epsilon_{t}$$
where $x_{t}$ is log abundance at time
$t$ and $\epsilon_{t} \sim Normal(0, \sigma^2$.
Observation error models are described in the help page of
pva.
The argument fixed can be used to fit the model assuming
a priori values of a subset of the parameters. For instance,
fixing theta equal to one reduces Theta-Logistic and
Gnerelized Beverton-Holt models to Logistic and Beverton-Holt
models respectively. The number of parameters that should be
fixed at most is $p-1$, where $p$ is the dimension of
the full model. See examples below and in pva
and model.select.
The fixed argument can be used to provide alternative
prior specification using the BUGS language.
In this case, values in fixed must be numeric.
Use a list when real fixed values (numeric) and priors (character)
are provided at the same time (see Examples).
Alternative priors can be useful
for testing insensitivity to priors, which is
a diagnostic sign of data cloning convergence.pvamodel-class, pvagompertz()
gompertz("poisson")
ricker("normal")
ricker("normal", fixed=c(a=5, sigma=0.5))
thetalogistic("none", fixed=c(theta=1))
bevertonholt("normal", fixed=c(theta=1))
## alternative priors
ricker("normal", fixed=c(a="a ~ dnorm(2, 1)"))@model
ricker("normal", fixed=list(a="a ~ dnorm(2, 1)", sigma=0.5))@modelRun the code above in your browser using DataLab